StorageMetric

Trait StorageMetric 

pub trait StorageMetric {
    // Required methods
    fn summarize<'a, I>(values: I) -> Self
       where I: IntoIterator<Item = &'a Self>,
             Self: Sized + 'a;
    fn incorporate(&mut self, other: Self, field_name: &'static str);
}
A trait that defines the semantics storage statistics are able to have

Required Methods

fn summarize<'a, I>(values: I) -> Self
where I: IntoIterator<Item = &'a Self>, Self: Sized + 'a,

Summarizes a set of measurements into a single representative value. Typically this function is used to summarize the measurements collected from each worker.

fn incorporate(&mut self, other: Self, field_name: &'static str)

Incorporate this value with another.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors