pub struct StorageCollectionsImpl { /* private fields */ }Expand description
Implementation of StorageCollections that is shallow-cloneable and uses a background task for doing work concurrently, in the background.
Implementations
Sourceimpl StorageCollectionsImpl
impl StorageCollectionsImpl
Sourcepub async fn new(
persist_location: PersistLocation,
persist_clients: Arc<PersistClientCache>,
metrics_registry: &MetricsRegistry,
_now: NowFn,
txns_metrics: Arc<TxnMetrics>,
envd_epoch: NonZeroI64,
read_only: bool,
connection_context: ConnectionContext,
txn: &dyn StorageTxn,
) -> Self
pub async fn new( persist_location: PersistLocation, persist_clients: Arc<PersistClientCache>, metrics_registry: &MetricsRegistry, _now: NowFn, txns_metrics: Arc<TxnMetrics>, envd_epoch: NonZeroI64, read_only: bool, connection_context: ConnectionContext, txn: &dyn StorageTxn, ) -> Self
Creates and returns a new StorageCollections.
Note that when creating a new StorageCollections, you must also reconcile it with the previous state using StorageCollections::initialize_state, StorageCollections::prepare_state, and StorageCollections::create_collections_for_bootstrap.